@@ -6,8 +6,6 @@ import pip
 import string
 import uuid
 
-from pkg_resources import DistributionNotFound, get_distribution
-
 
 class QaseUtils:
 
@@ -39,6 +37,10 @@ class QaseUtils:
     def get_thread_name() -> str:
         return f"{os.getpid()}-{threading.current_thread().name}"
 
+    @staticmethod
+    def parse_bool(value) -> bool:
+        return value in ("y", "yes", "true", "True", "TRUE", "1", 1, True)
+
     @staticmethod
     def uuid() -> str:
         return str(uuid.uuid4())
@@ -62,14 +64,6 @@ class QaseUtils:
     def get_filename(path) -> str:
         return os.path.basename(path)
 
-    @staticmethod
-    def package_version(name):
-        try:
-            version = get_distribution(name).version
-        except DistributionNotFound:
-            version = "unknown"
-        return version
-
 
 class StringFormatter(string.Formatter):
     """
